import type { IDS, PageQuery, PageResult } from '#/api/common';
import type { SpareVO } from '#/api/eims/spare/model';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  inoutList = '/eims/spare/listInout',
  root = '/eims/spare',
  spareExport = '/eims/spare/export',
  spareList = '/eims/spare/list'
}

/**
 * 查询【备件台账】列表
 * @param query
 * @returns {*}
 */

export function listSpare(params?: PageQuery) {
  return requestClient.get<PageResult<SpareVO>>(Api.spareList, { params });
}

export function listInout(params?: PageQuery) {
  return requestClient.get<PageResult<any>>(Api.inoutList, { params });
}

/**
 * 查询【备件台账】详细
 * @param spareId
 */
export function getSpare(spareId: any) {
  return requestClient.get<SpareVO>(`${Api.root}/${spareId}`);
}

/**
 * 新增【备件台账】
 * @param data
 */
export function addSpare(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改【备件台账】
 * @param data
 */
export function updateSpare(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除【备件台账】
 * @param spareIds
 */
export function delSpare(spareIds: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${spareIds}`);
}

/**
 * 导出【备件台账】
 * @param data
 */
export function spareExport(data: any) {
  return commonExport(Api.spareExport, data);
}
